package info.bukova.isspst.filters;

import info.bukova.isspst.BigDecimalUtils;
import info.bukova.isspst.StringUtils;
import info.bukova.isspst.data.JoinedItem;
import info.bukova.isspst.data.MUnitEmb;

import org.hamcrest.Description;
import org.hamcrest.Factory;
import org.hamcrest.Matcher;
import org.hamcrest.TypeSafeMatcher;

public class JoinedItemFilter implements Filter<JoinedItem>
{
	private JoinedItem condition;

	public JoinedItemFilter(JoinedItem cond)
	{
		this.condition = cond;
	}

	private static class JoinedItemMatcher extends TypeSafeMatcher<JoinedItem>
	{
		private JoinedItem condition;

		public JoinedItemMatcher(JoinedItem cond)
		{
			this.condition = cond;
		}

		@Override
		public void describeTo(Description desc)
		{
			desc.appendText("JoinedItem matches");
		}

		@Override
		public boolean matchesSafely(JoinedItem item)
		{
			boolean foundCode = StringUtils.isEqualForFilter(item.getCode(), condition.getCode());
			boolean foundName = StringUtils.isEqualForFilter(item.getName(), condition.getName());
			boolean foundTextItem = StringUtils.isEqualForFilter(item.getTextItem(), condition.getTextItem());
			boolean foundQuantity = BigDecimalUtils.isEqualByDecimalForFilter(item.getQuantity(), condition.getQuantity());
			boolean foundUnitPrice = BigDecimalUtils.isEqualByDecimalForFilter(item.getUnitPrice(), condition.getUnitPrice());
			boolean foundMUnit = MUnitEmb.isEqualMUnitEmbForFilter(item.getMunit(), condition.getMunit());
			boolean foundTotal = BigDecimalUtils.isEqualByDecimalForFilter(item.getTotal(), condition.getTotal());
			boolean foundDescription = StringUtils.isEqualForFilter(item.getDescription(), condition.getDescription());
			return (foundCode && foundName && foundTextItem && foundDescription && foundQuantity && foundUnitPrice && foundMUnit && foundTotal && foundDescription);
		}

		@Factory
		public static Matcher<JoinedItem> matchBuilding(JoinedItem item)
		{
			return new JoinedItemMatcher(item);
		}
	}

	@Override
	public JoinedItemMatcher matcher()
	{
		return new JoinedItemMatcher(condition);
	}

	@Override
	public String queryString()
	{
		return "";
	}
}
